Success message invisibly. NOTE: cloud processing
can take some time so the added file may not appear immediately.
For this reason, a sciencebase item json is NOT returned as is
done with other similar functions.
Arguments
sb_id
An sbitem object or a character ScienceBase ID corresponding to the item