powered by
Queries ScienceBase for the list of all available datatypes. This can be coupled with query_sb_datatype to query based on the type of data
query_sb_datatype
sb_datatypes(limit = 50, session = current_session())
Maximum number of returned items. Will do paging to retrieve results when limit is over 1000. Use with caution, queries 10k results are slow.
Session object from authenticate_sb
authenticate_sb
if (FALSE) { #return all datatypes (limit 50 by default) sb_datatypes() }
Run the code above in your browser using DataLab