This validates the underyling RCurl session. The session object
becomes invalid if the R session has been saved to disk or persisted through
an R restart. This verifies that the session object is either valid, or is a
NULL object, which means no session state is being persisted. Note, this does
not verify the credentials are valid or that you have permission to access
the SB item, so it does not guarantee a successful request.