This function quickly checks to see if an identifier exists.
It does a quick head request to skip the overhead of item metadta retrieval.
This will also return FALSE if the identifier exists but is associated
with an item that is unavailable due to permission restrictions.