logical should the files be scraped for metadata?
If TRUE, sciencebase will attempt to create extensions based on the files.
For example, for shapefiles, this will result in a shapefile extension
to be returned as a facet of the sciencebase item.
See item: "58069258e4b0824b2d1d422e" for an example.
session
Session object from authenticate_sb. Defaults to anonymous or
last authenticated session