Learn R Programming

sbtools (version 1.2.0)

item_get_parent: Get an item's parent ID

Description

Retrieves the parent of a supplied item based on the ScienceBase item tree hierarchy.

Usage

item_get_parent(sb_id, ..., session = current_session())

Value

An item object representing the parent of the supplied item.

Arguments

sb_id

An sbitem object or a character ScienceBase ID corresponding to the item

...

Additional parameters are passed on to GET, POST, HEAD, PUT, or DELETE

session

Session object from authenticate_sb. Defaults to anonymous or last authenticated session

Examples

Run this code
# \donttest{
item_get_parent("4f4e4b24e4b07f02db6aea14")

item_get_parent(item_get("4f4e4b24e4b07f02db6aea14"))
# }

Run the code above in your browser using DataLab