powered by
Retrieves the parent of a supplied item based on the ScienceBase item tree hierarchy.
item_get_parent(sb_id, ..., session = current_session())
An item object representing the parent of the supplied item.
An sbitem object or a character ScienceBase ID corresponding to the item
sbitem
Additional parameters are passed on to GET, POST, HEAD, PUT, or DELETE
GET
POST
HEAD
PUT
DELETE
Session object from authenticate_sb. Defaults to anonymous or last authenticated session
authenticate_sb
# \donttest{ item_get_parent("4f4e4b24e4b07f02db6aea14") item_get_parent(item_get("4f4e4b24e4b07f02db6aea14")) # }
Run the code above in your browser using DataLab