Remove an item from ScienceBase. This is not reversible and will delete
an item and its attached files. (advanced) Recursive is to be used with care
and could result in unexpected file deletion.
The maximum number of child items to remove when called with
recursive=TRUE.
recursive
logical, FALSE by default. CAUTION: setting recursive=TRUE
means that not only will this item be deleted, but so will all its child
items and their child items and so on.
session
Session object from authenticate_sb. Defaults to anonymous or
last authenticated session